@@ -2,6 +2,7 @@
 
 from copy import copy, deepcopy
 from io import SEEK_SET
+from threading import Lock
 from typing import Any
 
 from PIL import Image
@@ -51,6 +52,7 @@ class BaseImage:
         self.size, self.mode = c_image.size_mode
         self._c_image = c_image
         self._data = None
+        self._load_lock = Lock()
 
     @property
     def data(self):
@@ -109,8 +111,11 @@ class BaseImage:
             when reading `data` or `stride` property of image will be loaded automatically.
         """
         if not self._data:
-            self._data = self._c_image.data
-            self.size, _ = self._c_image.size_mode
+            with self._load_lock:
+                if not self._data:
+                    data = self._c_image.data
+                    self.size, _ = self._c_image.size_mode
+                    self._data = data
 
 
 class HeifDepthImage(BaseImage):
@@ -177,6 +182,9 @@ class HeifImage(BaseImage):
             self.info["xmp"] = xmp
         if heif_meta:
             self.info["heif"] = heif_meta
+        pixel_aspect_ratio = c_image.pixel_aspect_ratio
+        if pixel_aspect_ratio:
+            self.info["pixel_aspect_ratio"] = pixel_aspect_ratio
         save_colorspace_chroma(c_image, self.info)
         color_profile: dict[str, Any] = c_image.color_profile
         if color_profile:
@@ -461,7 +469,7 @@ class HeifFile:
             img.size,
             img.tobytes(),
         )
-        for key in ["bit_depth", "thumbnails", "icc_profile", "icc_profile_type"]:
+        for key in ["bit_depth", "thumbnails", "icc_profile", "icc_profile_type", "pixel_aspect_ratio"]:
             if key in image.info:
                 added_image.info[key] = image.info[key]
         for key in ["nclx_profile", "metadata"]:
